#!/usr/bin/perl
# 
# test script for Serene Bach libraries
# == written by T.Otani <ootani@segausers.gr.jp> ===
# == Copyright (C) 2004 SimpleBoxes/SerendipityNZ ==

# ======================================
use strict;
use warnings;
use lib qw(./ ../);
use sb::Test;
sb::Test::LoadAll->run();

package sb::Test::LoadAll;
use vars qw( $VERSION );
$VERSION = '0.07';
# 0.07 [2007/11/29] added sb::Net::Ping
# 0.06 [2007/09/17] added sb::Admin::CommentOption
# 0.05 [2007/08/17] added sb::App::Mobile/sb::Content::Mobile/sb::Content::Feed
# 0.04 [2007/08/16] added sb::App::Builder/sb::App::Counter
# 0.03 [2007/08/12] added sb::Build/sb::App::Receipt/sb::App::Feed/sb::App::Rsd
# 0.02 [2007/08/07] added sb::Driver::TextOld/sb::Plugin
# 0.01 [2007/07/31] added sb::Content
# 0.00 [2007/07/20] created
# --------------------------------------
# // public functions
sub run
{
	my $testcase = sb::Test->new();
	$testcase->add('loadall',\&_test,1);
	$testcase->run();
}
# --------------------------------------
# // private functions
sub _test
{
	# --- basic classes
	require sb;
	require sb::Config;
	require sb::InitParser;
	require sb::Interface;
	require sb::Object;
	require sb::Session;
	require sb::Template;
	require sb::TemplateManager;
	require sb::Lock;
	require sb::Time;
	require sb::Utils;
	require sb::Plugin;
	require sb::Build;
	# --- text
	require sb::Text;
	require sb::Text::autobreak;
	require sb::Text::autolink;
	require sb::Text::md5;
	# --- app
	require sb::App;
	require sb::App::Admin;
	require sb::App::Feed;
	require sb::App::Main;
	require sb::App::Mobile;
	require sb::App::Xmlrpc;
	require sb::App::Receipt;
	require sb::App::Rsd;
	require sb::App::Builder;
	require sb::App::Counter;
	# --- data
	require sb::Data;
	require sb::Data::Object;
	require sb::Data::Amazon;
	require sb::Data::Category;
	require sb::Data::Config;
	require sb::Data::Customdata;
	require sb::Data::Entry;
	require sb::Data::Image;
	require sb::Data::Link;
	require sb::Data::Message;
	require sb::Data::Plugin;
	require sb::Data::Session;
	require sb::Data::Template;
	require sb::Data::Trackback;
	require sb::Data::User;
	require sb::Data::Weblog;
	# --- driver
	require sb::Driver;
	require sb::Driver::Text;
	require sb::Driver::TextOld;
	require sb::Driver::SqlBase;
	require sb::Driver::Mysql;
	require sb::Driver::Sqlite;
	# --- file
	require sb::File;
	require sb::File::Audio;
	require sb::File::Dir;
	require sb::File::Image;
	require sb::File::MimeType;
	require sb::File::Object;
	require sb::File::Uploader;
	# --- language
	require sb::Language;
	require sb::Language::en;
	require sb::Language::ja;
	# --- local
	require sb::Local;
	require sb::Local::jp;
	require sb::Local::nz;
	# --- net
	require sb::Net;
	require sb::Net::Aws;
	require sb::Net::Mailer;
	require sb::Net::Ping;
	# --- content
	require sb::Content;
	require sb::Content::Common;
	require sb::Content::List;
	require sb::Content::Entry;
	require sb::Content::Message;
	require sb::Content::Trackback;
	require sb::Content::Profile;
	require sb::Content::Category;
	require sb::Content::Feed;
	require sb::Content::Mobile;
	# --- admin
	require sb::Admin::Amazon;
	require sb::Admin::Build;
	require sb::Admin::Category;
	require sb::Admin::EntryList;
	require sb::Admin::CommentOption;
	require sb::Admin::Message;
	require sb::Admin::Trackback;
	require sb::Admin::Editor;
	require sb::Admin::Entry;
	require sb::Admin::Help;
	require sb::Admin::Home;
	require sb::Admin::Link;
	require sb::Admin::List;
	require sb::Admin::Login;
	require sb::Admin::Preview;
	require sb::Admin::Profile;
	require sb::Admin::Quickpost;
	require sb::Admin::Template;
	require sb::Admin::Upload;
	require sb::Admin::User;
	return 1;
}
1;
__END__
